package ru.ulstu.extractor.mvc;

import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.ModelAttribute;
import org.springframework.web.bind.annotation.PostMapping;
import ru.ulstu.extractor.mvc.model.FilterForm;
import ru.ulstu.extractor.mvc.model.RepoForm;
import ru.ulstu.extractor.service.FilteringService;
import ru.ulstu.extractor.service.GitRepositoryService;

@Controller
public class GitExtractorController {
    private final FilteringService filteringService;
    private final GitRepositoryService gitRepositoryService;

    public GitExtractorController(FilteringService filteringService,
                                  GitRepositoryService gitRepositoryService) {
        this.filteringService = filteringService;
        this.gitRepositoryService = gitRepositoryService;
    }

    @GetMapping("/newRepo")
    public String indexNewRepo(Model model) {
        model.addAttribute("repoForm", new RepoForm());
        return "newRepo";
    }

    @GetMapping("/filtering")
    public String filter(Model model) {
        model.addAttribute("filterForm", new FilterForm());
        return "filtering";
    }

    @PostMapping("/sendRepo")
    public String sendRepo(@ModelAttribute RepoForm repoForm, Model model) {
        if (repoForm.getRepo() == null || repoForm.getRepo().isEmpty()) {
            model.addAttribute("error", "'Git' не должно быть пустым");
            return "newRepo";
        }
        model.addAttribute("filterForm", new FilterForm(repoForm.getRepo()));
        try {
            gitRepositoryService.cloneOrUpdateRepo(repoForm.getRepo());
        } catch (Exception ex) {
            model.addAttribute("error", ex.getMessage());
            return "newRepo";
        }
        return "filtering";
    }

    @PostMapping("/sendFilter")
    public String sendFilter(@ModelAttribute FilterForm filterForm, Model model) {
        if (filterForm.getFilter() == null || filterForm.getFilter().isEmpty()) {
            model.addAttribute("error", "'Строка' не должно быть пустым");
            return "filtering";
        }
        model.addAttribute("commits", filteringService.getCommits(filterForm.getFilter(), filterForm.getFilter()));
        return "resultRepo";
    }
}
